SplitIter

Trait SplitIter 

#[doc(hidden)]
pub(super) trait SplitIter: DoubleEndedIterator { // Required method fn finish(&mut self) -> Option<Self::Item>; }
An internal abstraction over the splitting iterators, so that splitn, splitn_mut etc can be implemented once.

Required Methods

fn finish(&mut self) -> Option<Self::Item>

Marks the underlying iterator as complete, extracting the remaining portion of the slice.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.27.0 · Source

impl<'a, T, P> SplitIter for RSplit<'a, T, P>
where P: FnMut(&T) -> bool,

1.27.0 · Source

impl<'a, T, P> SplitIter for RSplitMut<'a, T, P>
where P: FnMut(&T) -> bool,

Source

impl<'a, T, P> SplitIter for Split<'a, T, P>
where P: FnMut(&T) -> bool,

Source

impl<'a, T, P> SplitIter for SplitMut<'a, T, P>
where P: FnMut(&T) -> bool,